@@ -1,24 +1,24 @@
 /***************************************************************************
-
+  
   CScreen.h
-
+  
   (c) 2004-2006 - Daniel Campos Fernández <dcamposf@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.
-
+  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-
+  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301, USA.
-
+  
 ***************************************************************************/
 
 #ifndef __CSCREEN_H
@@ -34,7 +34,6 @@ extern GB_DESC ScreensDesc[];
 extern GB_DESC DesktopDesc[];
 extern GB_DESC ApplicationDesc[];
 
-extern char *CAPPLICATION_Theme;
 extern GB_ARRAY CAPPLICATION_Restart;
 extern bool CAPPLICATION_MiddleClickPaste;
 
@@ -52,6 +51,6 @@ typedef
 	}
 	CSCREEN;
 	
-void APPLICATION_send_change_event(int change);
+void APPLICATION_send_change_event(const char *change);
 
 #endif
