@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'c_webview.h'
 **
-** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
+** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.1)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -18,7 +18,7 @@
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'c_webview.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 69
-#error "This file was generated using the moc from 6.10.0. It"
+#error "This file was generated using the moc from 6.10.1. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -166,7 +166,9 @@ template <> constexpr inline auto WebViewSignalManager::qt_create_metaobjectdata
         "ok",
         "newWindowRequested",
         "QWebEngineNewWindowRequest&",
-        "request"
+        "request",
+        "findTextFinished",
+        "QWebEngineFindTextResult"
     };
 
     QtMocHelpers::UintData qt_methods {
@@ -194,6 +196,10 @@ template <> constexpr inline auto WebViewSignalManager::qt_create_metaobjectdata
         QtMocHelpers::SlotData<void(QWebEngineNewWindowRequest &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
             { 0x80000000 | 13, 14 },
         }}),
+        // Slot 'findTextFinished'
+        QtMocHelpers::SlotData<void(const QWebEngineFindTextResult &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
+            { 0x80000000 | 16, 2 },
+        }}),
     };
     QtMocHelpers::UintData qt_properties {
     };
@@ -225,6 +231,7 @@ void WebViewSignalManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
         case 5: _t->loadProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
         case 6: _t->loadFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
         case 7: _t->newWindowRequested((*reinterpret_cast<std::add_pointer_t<QWebEngineNewWindowRequest&>>(_a[1]))); break;
+        case 8: _t->findTextFinished((*reinterpret_cast<std::add_pointer_t<QWebEngineFindTextResult>>(_a[1]))); break;
         default: ;
         }
     }
@@ -249,14 +256,14 @@ int WebViewSignalManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
     if (_id < 0)
         return _id;
     if (_c == QMetaObject::InvokeMetaMethod) {
-        if (_id < 8)
+        if (_id < 9)
             qt_static_metacall(this, _c, _id, _a);
-        _id -= 8;
+        _id -= 9;
     }
     if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
-        if (_id < 8)
+        if (_id < 9)
             *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
-        _id -= 8;
+        _id -= 9;
     }
     return _id;
 }
