@@ -1,24 +1,24 @@
 /***************************************************************************
-
+  
   image.c
-
-  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
+  
+  (c) Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.
-
+  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-
+  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301, USA.
-
+  
 ***************************************************************************/
 
 #define __IMAGE_C
@@ -2394,6 +2394,136 @@ void IMAGE_balance(GB_IMG *img, int brightness, int contrast, int gamma, int hue
 
 //---------------------------------------------------------------------------
 
+#if 0
+static void rgb2lch(double color[])
+{
+	double r = color[0];
+	double g = color[1];
+	double b = color[2];
+	
+	double x, y, z;
+	double l, u, v;
+	double c, h;
+	
+	
+	if (r > .04045)
+		r = pow((r + .055) / 1.055, 2.4);
+	else
+		r = r / 12.92;
+
+	if (g > .04045)
+		g = pow((g + .055) / 1.055, 2.4);
+	else
+		g = g / 12.92;
+
+	if (b > .04045)
+		b = pow((b + .055) / 1.055, 2.4);
+	else
+		b = b / 12.92;
+
+	x = ((r * .412453) + (g * .357580) + (b * .180423));
+	y = ((r * .212671) + (g * .715160) + (b * .072169));
+	z = ((r * .019334) + (g * .119193) + (b * .950227));
+
+	/*x = x / 95.047 * 100;
+	z = z / 108.883 * 100;*/
+
+	if (x > .008856)
+		x = pow(x, (1.0 / 3.0));
+	else
+		x = (x * 7.787) + (16.0 / 116.0);
+
+	if (y > .008856)
+		y = pow(y, (1.0 / 3.0));
+	else
+		y = (y * 7.787) + (16.0 / 116.0);
+
+	if (z > .008856)
+		z = pow(z, (1.0 / 3.0));
+	else
+		z = (z * 7.787) + (16.0 / 116.0);
+
+	l = (116.0 * y) - 16.0f;
+	u = 500.0 * (x - y);
+	v = 200.0 * (y - z);
+	
+	c = sqrt(u * u + v * v);
+	
+	if (c < 0.00000001)
+		h = 0;
+	else
+	{
+		h = atan2(v, u) * 57.29577951308232087680;  /* (180 / pi) */
+		if ( h < 0.0)
+			h += 360.0;
+	}
+	
+	color[0] = l;
+	color[1] = c;
+	color[2] = h;
+}
+
+
+static void lch2rgb(double color[])
+{
+	double l = color[0];
+	double c = color[1];
+	double h = color[2];
+	
+	double u, v;
+	double x, y, z;
+	double r, g, b;
+	
+	u = cos(h * 0.01745329251994329577) * c;
+	v = sin(h * 0.01745329251994329577) * c;
+
+	y = (l + 16.0 ) / 116.0;
+	x = u / 500.0 + y;
+	z = y - v / 200.0;
+
+	if (x > 0.206896551724138)
+		x = pow(x, 3);
+	else
+		x = (x - 16.0 / 116.0) / 7.787;
+
+	if (y > 0.206896551724138)
+		y = pow(y, 3);
+	else
+		y = (y - 16.0 / 116.0) / 7.787;
+
+	if (z > 0.206896551724138)
+		z = pow(z, 3);
+	else
+		z = (z - 16.0 / 116.0) / 7.787;
+
+	/*x = x * 95.047 / 100;
+	z = z * 108.883 / 100;*/
+	
+	r = (x * 3.240479) + (y * -1.537150) + (z * -.498535);
+	g = (x * -.969256) + (y *  1.875992) + (z * .041556);
+	b = (x * .055648) +  (y * -.204043) + (z * 1.057311);
+
+	if (r > 0.0031308)
+		r = 1.055 * pow(r, 1/2.4) - 0.055;
+	else
+		r = 12.92 * r;
+
+	if (g > 0.0031308)
+		g = 1.055 * pow(g, 1/2.4) - 0.055;
+	else
+		g = 12.92 * g;
+
+	if (b > 0.0031308)
+		b = 1.055 * pow(b, 1/2.4) - 0.055;
+	else
+		b = 12.92 * b;
+	
+	color[0] = MinMax(r, 0, 1);
+	color[1] = MinMax(g, 0, 1);
+	color[2] = MinMax(b, 0, 1);
+}
+#endif
+
 void IMAGE_invert(GB_IMG *img, bool keep_hue) // GB_COLOR bg, GB_COLOR fg)
 {
 	/*static uchar lum[256];
@@ -2402,6 +2532,8 @@ void IMAGE_invert(GB_IMG *img, bool keep_hue) // GB_COLOR bg, GB_COLOR fg)
 	GET_POINTER(img, p, pm);
 	uint col;
 	int format = img->format;
+	int hcol, scol, vcol;
+	int r, g, b;
 	
 	SYNCHRONIZE(img);
 	
@@ -2432,10 +2564,39 @@ void IMAGE_invert(GB_IMG *img, bool keep_hue) // GB_COLOR bg, GB_COLOR fg)
 			*p++ = GB_COLOR_to_format(gcol, format);
 		}*/
 
-		while (p != pm)
+		//double color[3];
+		
+	while (p != pm)
 		{
 			col = BGRA_from_format(*p, format);
-			*p++ = BGRA_to_format(RGBA(255 - (GREEN(col) + BLUE(col)) / 2, 255 - (RED(col) + BLUE(col)) / 2, 255 - (RED(col) + GREEN(col)) / 2, ALPHA(col)), format);
+			
+#if 0
+			color[0] = RED(col) / 255.0;
+			color[1] = GREEN(col) / 255.0;
+			color[2] = BLUE(col) / 255.0;
+			
+			/*rgb2lab(color);
+			l = 100 - color[0];
+			
+			color[0] = (255 - (GREEN(col) + BLUE(col)) / 2) / 255.0;
+			color[1] = (255 - (RED(col) + BLUE(col)) / 2) / 255.0;
+			color[2] = (255 - (RED(col) + GREEN(col)) / 2) / 255.0;*/
+			
+			//fprintf(stderr, "rgb: %g %g %g\n", color[0], color[1], color[2]);
+			rgb2lch(color);
+			color[0] = 100 - color[0];
+			lch2rgb(color);
+			//fprintf(stderr, "-> rgb: %g %g %g\n", color[0], color[1], color[2]);
+			
+			*p++ = BGRA_to_format(RGBA(color[0] * 255.0, color[1] * 255.0, color[2] * 255.0, ALPHA(col)), format);
+#endif
+			
+			COLOR_rgb_to_hsv(255 - RED(col), 255 - GREEN(col), 255 - BLUE(col), &hcol, &scol, &vcol);
+			hcol = (hcol + 180) % 360;
+			COLOR_hsv_to_rgb(hcol, scol, vcol, &r, &g, &b);
+			*p++ = BGRA_to_format(RGBA(r, g, b, ALPHA(col)), format);
+			
+			//*p++ = BGRA_to_format(RGBA(255 - (GREEN(col) + BLUE(col)) / 2, 255 - (RED(col) + BLUE(col)) / 2, 255 - (RED(col) + GREEN(col)) / 2, ALPHA(col)), format);
 		}
 	}
 	/*else
